@@ -106,8 +106,8 @@ evalElement el
     | Group        fm d l   <- el = when' ((/=) [] <$> tryGroup l) $
                                     return . outputList fm d =<< evalElements l
     | Date     _ _ _  _ _ _ <- el = evalDate el
-    | Label    s f fm _     <- el = formatLabel f fm True s -- FIXME !!
-    | Term     s f fm p     <- el = formatLabel f fm p s
+    | Label    s f fm p     <- el = formatLabel f fm True False s -- FIXME !!
+    | Term     s f fm p     <- el = formatLabel f fm p    True  s
     | Names    s n fm d sub <- el = modify (\st -> st { contNum = [] }) >>
                                     ifEmpty (evalNames False s n d)
                                             (withNames s el $ evalElements sub)
