@@ -36,7 +36,7 @@ evalNames skipEdTrans ns nl d
       sb == "editor" && sa == "translator" = do
         aa <- getAgents' sa
         ab <- getAgents' sb
-        if aa == ab
+        if aa /= [] && aa == ab
            then modify (\s -> s { edtrans = True }) >>
                 evalNames True [sa] nl d
            else evalNames True  ns  nl d
@@ -107,7 +107,7 @@ formatNames ea del p s as n
 
     | NameLabel f fm pl <- n = when' (isVarSet s) $ do
         b <- gets edtrans
-        res <- formatLabel f fm (isPlural pl $ length as) $ if b then "editortranslator" else s
+        res <- formatLabel f fm (isPlural pl $ length as) False $ if b then "editortranslator" else s
         modify $ \st -> st { edtrans = False }
         updateEtal [res]
         return res
@@ -320,15 +320,18 @@ unwords' = unwords . words . foldr concatWord []
                         then w ++     ws
                         else w ++ ' ':ws
 
-formatLabel :: Form -> Formatting -> Bool -> String -> State EvalState [Output]
-formatLabel f fm p s
+formatLabel :: Form -> Formatting -> Bool -> Bool -> String -> State EvalState [Output]
+formatLabel f fm p isTerm s
     | "locator" <- s = when' (gets (citeLocator . cite . env) >>= return . (/=) []) $ do
                        (l,v) <- getLocVar
                        form (\fm' -> return . flip OLoc emptyFormatting . output fm') id l ('-' `elem` v)
     | "page"    <- s = checkPlural
     | "volume"  <- s = checkPlural
     | "ibid"    <- s = format' s p
-    | otherwise      = if isRole s then form (\fm' x -> [OLabel x fm']) id s p else format s p
+    | not isTerm
+    , isRole       s = do a <- getAgents' (if s == "editortranslator" then "editor" else s)
+                          if a /= [] then form (\fm' x -> [OLabel x fm']) id s p else return []
+    | otherwise      = format s p
     where
       isRole = flip elem ["author", "collection-editor", "composer", "container-author"
                          ,"director", "editor", "editorial-director", "editortranslator"
